<?php

namespace App\Tools;

use Symfony\Component\HttpFoundation\Session\SessionInterface;
use Symfony\Component\Security\Core\Security;
use Symfony\Component\Security\Core\Role\Role;

class RoleCheck
{
    private $security;
    private $session;

    public function __construct(Security $security, SessionInterface $session)
    {
        $this->security = $security;
        $this->session = $session;
    }

    /**
     * Fonction permettant de vérifier que l'utilisateur a choisi ce rôle si il en a plusieurs ou sinon qu'il a bien ce rôle
     *
     * @param  string  $role Role
     * @return boolean       Boolean
     */
    public function isGranted($role)
    {
        if ($this->session->has('_groupId')) {
            $group = $this->session->get('_groupId');
            return (in_array($role, $group->getRoles()) && ($this->security->getUser() && $this->security->getUser()->isGranted($role)));
        } else {
            return ($this->security->getUser() && $this->security->getUser()->isGranted($role));
        }
    }

    public function getCurrentRole()
    {
        if ($this->session->has('_groupId')) {
            return $this->session->get('_groupId');
        } else {
            if (count($this->security->getUser()->getRoles()) == 1) {
                return $this->security->getUser()->getRoles()[0];
            } elseif (count($this->security->getUser()->getRoles()) <= 0) {
                throw new \Exception('Utilisateur sans rôle => Impossible de faire une transaction ! ');
            } elseif (count($this->security->getUser()->getGroups()) == 1) {
                return $this->security->getUser()->getGroups()[0];
            } else {
                // $roles = $this->security->getUser()->getRoles();
                // if (in_array('ROLE_USER', $roles)) {
                //     unset($roles[array_search('ROLE_USER', $roles)]);
                // }
                // if (count($this->security->getUser()->getRoles()) == 1) {
                //     return $this->security->getUser()->getRoles()[0];
                // } else {
                //     return new Role('ROLE_USER');
                // }
                throw new \Exception('Utilisateur avec plusieurs rôles devant choisir le rôle avant de faire une transaction ! ');
            }
        }
    }
}
